@@ -7,6 +7,8 @@
 */
 
 #include "uniqueapphandler.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "core.h"
 
 #include "processes.h"
@@ -85,8 +87,8 @@ UniqueAppHandler::UniqueAppHandler(Plugin *plugin)
     d->mPlugin = plugin;
     QDBusConnection session = QDBusConnection::sessionBus();
     const QString appName = plugin->objectName();
-    session.registerService(QLatin1String("org.kde.") + appName);
-    const QString objectName = QLatin1Char('/') + appName + QLatin1String("_PimApplication");
+    session.registerService("org.kde."_L1 + appName);
+    const QString objectName = QLatin1Char('/') + appName + "_PimApplication"_L1;
     session.registerObject(objectName, this, QDBusConnection::ExportAllSlots);
 }
 
@@ -94,7 +96,7 @@ UniqueAppHandler::~UniqueAppHandler()
 {
     QDBusConnection session = QDBusConnection::sessionBus();
     const QString appName = parent()->objectName();
-    session.unregisterService(QLatin1String("org.kde.") + appName);
+    session.unregisterService("org.kde."_L1 + appName);
 }
 
 // DBUS call
@@ -165,7 +167,7 @@ UniqueAppWatcher::UniqueAppWatcher(UniqueAppHandlerFactoryBase *factory, Plugin
     d->mPlugin = plugin;
 
     // The app is running standalone if 1) that name is known to D-Bus
-    const QString serviceName = QLatin1String("org.kde.") + plugin->objectName();
+    const QString serviceName = "org.kde."_L1 + plugin->objectName();
     // Needed for wince build
 #undef interface
     d->mRunningStandalone = QDBusConnection::sessionBus().interface()->isServiceRegistered(serviceName);
@@ -220,7 +222,7 @@ void KontactInterface::UniqueAppWatcher::slotApplicationRemoved(const QString &n
         return;
     }
 
-    const QString serviceName = QLatin1String("org.kde.") + d->mPlugin->objectName();
+    const QString serviceName = "org.kde."_L1 + d->mPlugin->objectName();
     if (name == serviceName && d->mRunningStandalone) {
         d->mFactory->createHandler(d->mPlugin);
         d->mRunningStandalone = false;
